@@ -21,16 +21,13 @@
 ### (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 ### THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-import os
 import _vc
 
 class Vc(_vc.Vc):
 
     CMD = "true"
     NAME = "Null"
-
-    def __init__(self, location):
-        pass
+    VC_DIR = "." # Accept any directory
 
     def commit_command(self, message):
         return [self.CMD,"commit","-m",message]
